int N_ROXES    = 256;
int MIN_ROT    = 128;
int ROT_RANGE  = 2556;
int MIN_SHADE  = 16;
int MAX_SHADE  = 64;
int MAX_WOBBLE = 24;
int MAX_WIDTH  = 60;

Roxor[] roxes;

void setup() {
  background(0);
  smooth();
  frameRate(30);
  size(window.innerWidth, window.innerHeight);
  noStroke();

  roxes = new Roxor[N_ROXES];
  for(int i=0;i<roxes.length;i++) {
    int x = (int)random(width);
    int y = (int)random(height);
    int w = (int)random(MAX_WIDTH);
    float rot = PI/(MIN_ROT + random(ROT_RANGE));
    roxes[i] = new Roxor(x,y,w,rot);
  }
}

void draw() {
  background(0);
  for(int i=0;i<roxes.length;i++) {
    roxes[i].update();
  }
}

class Roxor {

  int x,y;
  int w;
  float rot,rincr;
  float wobble;
  float shade;
  float scaleFactor;
  float easing;
  int sides;

  public Roxor(int x, int y, int w, float rincr) {
    this.x = x;
    this.y = y;
    this.w = w;
    this.rot = PI-random(TWO_PI);
    this.rincr = rincr;
    this.rincr = (ceil(random(2))>1) ? this.rincr : 0-this.rincr;
    this.wobble = MAX_WOBBLE/2 - random(MAX_WOBBLE);
    this.shade = MIN_SHADE + random(MAX_SHADE - MIN_SHADE);
    this.scaleFactor = 0.0;
    this.easing = 0.0025 + random(0.095);
    this.sides = 5 + ceil(random(5));
  }

  public void update() {
    fill(this.shade);
    pushMatrix();
    translate(x,y);

    // ease in
    if (this.scaleFactor < 1.0) {
      float remaining = 1.0 - this.scaleFactor;
      this.scaleFactor += remaining * this.easing;
      scale(this.scaleFactor);
    }

    rotate(this.rot += this.rincr);
    polygon(this.wobble,this.wobble,w,this.sides);
    popMatrix();
  }

  void polygon(float x, float y, float radius, int npoints) {
    float angle = TWO_PI / npoints;
    beginShape();
    for (float a = 0; a < TWO_PI; a += angle) {
      float sx = x + cos(a) * radius;
      float sy = y + sin(a) * radius;
      vertex(sx, sy);
    }
    endShape(CLOSE);
  }
}
